if(!self.define){let e,i={};const n=(n,s)=>(n=new URL(n+".js",s).href,i[n]||new Promise(i=>{if("document"in self){const e=document.createElement("script");e.src=n,e.onload=i,document.head.appendChild(e)}else e=n,importScripts(n),i()}).then(()=>{let e=i[n];if(!e)throw new Error(`Module ${n} didn’t register its module`);return e}));self.define=(s,r)=>{const o=e||("document"in self?document.currentScript.src:"")||location.href;if(i[o])return;let c={};const d=e=>n(e,o),t={module:{uri:o},exports:c,require:d};i[o]=Promise.all(s.map(e=>t[e]||d(e))).then(e=>(r(...e),c))}}define(["./workbox-8c29f6e4"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"registerSW.js",revision:"1872c500de691dce40960bb85481de07"},{url:"logo.png",revision:"5134e0d39120473292c948cd493c7edd"},{url:"index.html",revision:"a99834955efabfe54d874cc5ec4e1ede"},{url:"favicon.ico",revision:"6bdec6fec50d9d4cc928c541d958c4b5"},{url:"assets/index-DobFHZ7L.css",revision:null},{url:"assets/index-D-8yNyFt.js",revision:null},{url:"logo.png",revision:"5134e0d39120473292c948cd493c7edd"},{url:"manifest.webmanifest",revision:"0eca3d5f75071d251c1316e666bd150d"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("/index.html")))});
