"""MCP (Model Context Protocol) server for Tether.

Provides a thin wrapper over the REST API, exposing Tether functionality
as MCP tools that can be used by MCP-compatible agents like Claude Code.
"""
