"""Compatibility shim: re-exports from agent_tether.discord.pairing_state."""
# ruff: noqa: F401
from agent_tether.discord.pairing_state import (
    DiscordPairingState,
    load_or_create,
    save,
)
