"""Compatibility shim: re-exports from agent_tether.manager and tether.bridges.glue."""
# ruff: noqa: F401
from agent_tether.manager import BridgeManager
from tether.bridges.glue import bridge_manager
